#include <bits/stdc++.h>
using namespace std;

void vypis_strom(const vector< pair<int,int> > hrany) {
    for (auto h : hrany) cout << h.first+1 << " " << h.second+1 << "\n";
}

typedef vector< vector<int> > rooted_tree;
typedef vector< vector<int> > tree;

vector<int> find_longest_path(const tree &T, int start) {
    vector<int> dist(T.size(), 987654321), from(T.size(), -1);
    queue<int> Q;
    Q.push(start);
    dist[start] = 0;
    int last = start;
    while (!Q.empty()) {
        int where = Q.front(); Q.pop();
        for (int v : T[where]) {
            if (dist[v] <= dist[where]+1) continue;
            dist[v] = dist[where]+1;
            from[v] = where;
            Q.push(v);
            last = v;
        }
    }
    vector<int> answer;
    while (true) {
        answer.push_back(last);
        last = from[last];
        if (last == -1) break;
    }
    reverse( answer.begin(), answer.end() );
    return answer;
}

vector<int> find_centers(const tree &T) {
    vector<int> path1 = find_longest_path(T,0);
    if (path1 == vector<int>{-1}) return {};
    vector<int> path2 = find_longest_path(T,path1.back());
    int L = path2.size();
    if (L % 2 == 0) {
        return { path2[L/2 - 1], path2[L/2] };
    } else {
        return { path2[L/2] };
    }
}

bool is_tree(const tree &T) {
    return !find_centers(T).empty();
}

rooted_tree root_tree(const tree &T, int root) {
    rooted_tree R(T.size());
    vector<int> dist(T.size(), 987654321);
    queue<int> Q;
    Q.push(root);
    dist[root] = 0;
    while (!Q.empty()) {
        int where = Q.front(); Q.pop();
        for (int v : T[where]) {
            if (dist[v] <= dist[where]+1) continue;
            dist[v] = dist[where]+1;
            R[where].push_back(v);
            Q.push(v);
        }
    }
    return R;
}

void dfs_label(const rooted_tree &R, map< vector<int>, int> &label_map, vector<int> &labels, int v) {
    vector<int> children;
    for (int w : R[v]) {
        dfs_label(R,label_map,labels,w);
        children.push_back( labels[w] );
    }
    sort( children.begin(), children.end() );
    if (!label_map.count(children)) {
        int new_label = label_map.size();
        label_map[children] = new_label;
    }
    labels[v] = label_map[children];
}

bool are_isomorphic_rooted(const rooted_tree &R1, int root1, const rooted_tree &R2, int root2) {
    map< vector<int>, int > label_map;
    vector<int> labels1( R1.size(), -1 ), labels2( R2.size(), -1 );
    dfs_label(R1, label_map, labels1, root1);
    dfs_label(R2, label_map, labels2, root2);
    return labels1[root1] == labels2[root2];
}

bool are_isomorphic(const tree &T1, const tree &T2) {
    for (int r1 : find_centers(T1)) for (int r2 : find_centers(T2)) {
        rooted_tree R1 = root_tree(T1,r1), R2 = root_tree(T2,r2);
        if (are_isomorphic_rooted(R1,r1,R2,r2)) return true;
    }
    return false;
}

bool are_isomorphic(int N, const vector<pair<int,int> > &E1, const vector<pair<int,int> > &E2) {
    tree T1(N), T2(N);
    for (auto e : E1) { T1[e.first].push_back(e.second); T1[e.second].push_back(e.first); }
    for (auto e : E2) { T2[e.first].push_back(e.second); T2[e.second].push_back(e.first); }
    return are_isomorphic(T1,T2);
}

void error(const string &msg) { cout << msg << endl; exit(1); }

int get_sef(vector<int> &sef, int x) {
    if (sef[x] == x) return x;
    return sef[x] = get_sef(sef, sef[x]);
}

vector< pair<int,int> > vyrob_nahodny_strom(vector<int> cisla_velkych, vector<int> stupne_velkych, vector<int> cisla_listov) {
    vector<int> sef( cisla_velkych.size() );
    iota( sef.begin(), sef.end(), 0 );
    int komponentov = cisla_velkych.size();

    vector< pair<int,int> > hrany;
    while (komponentov > 1) {
        int x = rand() % cisla_velkych.size();
        int y = rand() % cisla_velkych.size();
        if (stupne_velkych[x] == 0 || stupne_velkych[y] == 0) continue;
        int sx = get_sef(sef,x);
        int sy = get_sef(sef,y);
        if (sx == sy) continue;
        --stupne_velkych[x]; --stupne_velkych[y];
        hrany.emplace_back( cisla_velkych[x], cisla_velkych[y] );
        if (rand()%2) sef[sx] = sy; else sef[sy] = sx;
        --komponentov;
    }
    for (unsigned i=0; i<cisla_velkych.size(); ++i) {
        while (stupne_velkych[i]--) {
            int list = cisla_listov.back();
            cisla_listov.pop_back();
            hrany.push_back( { cisla_velkych[i], list } );
        }
    }
    return hrany;
}

int main() {
    int T; cin >> T;
    int N; cin >> N;
    vector<int> cisla_velkych, stupne_velkych, cisla_listov;
    int sumd = 0;
    for (int n=0; n<N; ++n) { 
        int d; cin >> d; sumd += d; 
        if (d > 1) { cisla_velkych.push_back(n); stupne_velkych.push_back(d); }
        if (d == 1) cisla_listov.push_back(n);
    }
    if (sumd != 2*(N-1)) { cout << "0\n"; return 0; }
    if (N == 2) { cout << "1\n1 2\n"; return 0; }
    
    vector< pair<int,int> > riesenie1 = vyrob_nahodny_strom(cisla_velkych, stupne_velkych, cisla_listov);
    for (int kolo=0; kolo<10; ++kolo) {
        vector< pair<int,int> > riesenie2 = vyrob_nahodny_strom(cisla_velkych, stupne_velkych, cisla_listov);
        if (!are_isomorphic(N,riesenie1,riesenie2)) {
            cout << "2\n";
            vypis_strom(riesenie1);
            vypis_strom(riesenie2);
            return 0;
        }
    }
    cout << "1\n";
    vypis_strom(riesenie1);
}
